## Overview
## Documentation
## Installation
```
pip install aioqui
```
### Package dependencies
includes ```pip install pyside6 qasync loguru```

speedups ```pip install aiodns ujson cchardet uvloop```

depending on modules [optional] ```pip install aiohttp uvicorn```
